@@ -1378,7 +1378,11 @@ void Application::handleActivate(const QStringList& arguments)
 #endif
 #if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 83, 0)
     if (KWindowSystem::isPlatformWayland()) {
-        KWindowSystem::setCurrentXdgActivationToken(qEnvironmentVariable("XDG_ACTIVATION_TOKEN"));
+        const QString token = qEnvironmentVariable("XDG_ACTIVATION_TOKEN");
+        if (!token.isEmpty()) {
+            KWindowSystem::setCurrentXdgActivationToken(token);
+            qunsetenv("XDG_ACTIVATION_TOKEN");
+        }
     }
 #endif
     mainWindow->activateAndRaiseWindow();
