@@ -122,6 +122,7 @@ class Application : public QApplication
         void doInlineAutoreplace(KTextEdit* textEdit) const;
 
         void newInstance(QCommandLineParser *args);
+        void restoreInstance();
 
         static void openUrl(const QString& url);
 
@@ -173,6 +174,9 @@ class Application : public QApplication
 
     private:
         void implementRestart();
+        enum AutoConnectMode { NoAutoConnect, AutoConnect };
+        enum WindowRestoreMode { NoWindowRestore, WindowRestore };
+        void createMainWindow(AutoConnectMode autoConnectMode, WindowRestoreMode restoreMode);
 
     private:
         ConnectionManager* m_connectionManager;
