@@ -1,25 +1,16 @@
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2005 İsmail Dönmez <ismail@kde.org.tr>
+    Based on the code by :
+    SPDX-FileCopyrightText: 2002 Carsten Pfeiffer <pfeiffer@kde.org>
+*/
+
 #ifndef KONVIBOOKMARKHANDLER_H
 #define KONVIBOOKMARKHANDLER_H
 
-/*
-  Copyright (c) 2005 by İsmail Dönmez <ismail@kde.org.tr>
-
-  *************************************************************************
-  *                                                                       *
-  * This program is free software; you can redistribute it and/or modify  *
-  * it under the terms of the GNU General Public License as published by  *
-  * the Free Software Foundation; either version 2 of the License, or     *
-  * (at your option) any later version.                                   *
-  *                                                                       *
-  *************************************************************************
-
-Based on the code by :
-Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>
-
-*/
-
-#include <kbookmarkmanager.h>
-#include <kbookmarkowner.h>
+#include <KBookmarkManager>
+#include <KBookmarkOwner>
 
 
 class QString;
@@ -49,5 +40,8 @@ class KonviBookmarkHandler : public QObject, public KBookmarkOwner
         MainWindow* m_mainWindow;
         KBookmarkMenu *m_bookmarkMenu;
         QString m_file;
+
+        Q_DISABLE_COPY(KonviBookmarkHandler)
 };
+
 #endif                                            // KONVIBOOKMARKHANDLER_H
