@@ -51,7 +51,7 @@ void QuickButtons_Config::setButtonsListView(const QStringList &buttonList)
     buttonListView->clear();
 
     for (const QString& definition : buttonList) {
-        QTreeWidgetItem *item = new QTreeWidgetItem(buttonListView, QStringList {
+        auto *item = new QTreeWidgetItem(buttonListView, QStringList {
             definition.section(QLatin1Char(','), 0, 0),
             definition.section(QLatin1Char(','), 1)
         });
@@ -166,7 +166,7 @@ void QuickButtons_Config::nameChanged(const QString& newName)
     // rename item
     item->setText(0,newName);
     // tell the config system that something has changed
-    if(!m_newItemSelected) emit modified();
+    if(!m_newItemSelected) Q_EMIT modified();
   }
 }
 
@@ -182,7 +182,7 @@ void QuickButtons_Config::actionChanged(const QString& newAction)
     // rename item
     item->setText(1,newAction);
     // tell the config system that something has changed
-    if(!m_newItemSelected) emit modified();
+    if(!m_newItemSelected) Q_EMIT modified();
   }
 }
 
@@ -190,7 +190,7 @@ void QuickButtons_Config::actionChanged(const QString& newAction)
 void QuickButtons_Config::addEntry()
 {
   // add new item at the bottom of list view
-  QTreeWidgetItem* newItem = new QTreeWidgetItem(buttonListView, buttonListView->topLevelItemCount());
+  auto* newItem = new QTreeWidgetItem(buttonListView, buttonListView->topLevelItemCount());
 
   if (newItem)
   {
@@ -204,7 +204,7 @@ void QuickButtons_Config::addEntry()
     // select all text to make overwriting easier
     nameInput->selectAll();
     // tell the config system that something has changed
-    emit modified();
+    Q_EMIT modified();
   }
 }
 
@@ -237,7 +237,7 @@ void QuickButtons_Config::removeEntry()
       entrySelected(nullptr);
     }
     // tell the config system that somethig has changed
-    emit modified();
+    Q_EMIT modified();
   }
 }
 
