@@ -220,7 +220,7 @@ namespace Konversation
         void WhiteBoardToolBar::clearClicked()
         {
             //TODO ask for confirm
-            emit clear();
+            Q_EMIT clear();
         }
 
         void WhiteBoardToolBar::saveClicked()
@@ -236,7 +236,7 @@ namespace Konversation
                 QStringList saveList = fileDialog->selectedFiles();
                 qCDebug(KONVERSATION_LOG) << saveList;
                 if (!saveList.isEmpty())
-                emit save(saveList.at(0));
+                Q_EMIT save(saveList.at(0));
             }
             delete fileDialog;
         }
@@ -337,7 +337,7 @@ namespace Konversation
             if (checked)
             {
                 unCheckOtherButtons(button);
-                emit toolChanged(tool);
+                Q_EMIT toolChanged(tool);
             }
             else
             {
@@ -385,12 +385,12 @@ namespace Konversation
                 if (m_rectanglePushButton->isChecked())
                 {
                     qCDebug(KONVERSATION_LOG) << "emit rectangle";
-                    emit toolChanged(WhiteBoardGlobals::Rectangle);
+                    Q_EMIT toolChanged(WhiteBoardGlobals::Rectangle);
                 }
                 else if (m_ellipsePushButton->isChecked())
                 {
                     qCDebug(KONVERSATION_LOG) << "emit ellipse";
-                    emit toolChanged(WhiteBoardGlobals::Ellipse);
+                    Q_EMIT toolChanged(WhiteBoardGlobals::Ellipse);
                 }
             }
             else if (selectedRow == 1)
@@ -398,12 +398,12 @@ namespace Konversation
                 if (m_rectanglePushButton->isChecked())
                 {
                     qCDebug(KONVERSATION_LOG) << "emit filledrectangle";
-                    emit toolChanged(WhiteBoardGlobals::FilledRectangle);
+                    Q_EMIT toolChanged(WhiteBoardGlobals::FilledRectangle);
                 }
                 else if (m_ellipsePushButton->isChecked())
                 {
                     qCDebug(KONVERSATION_LOG) << "emit filledellipse";
-                    emit toolChanged(WhiteBoardGlobals::FilledEllipse);
+                    Q_EMIT toolChanged(WhiteBoardGlobals::FilledEllipse);
                 }
             }
         }
@@ -458,11 +458,11 @@ namespace Konversation
                         tPaint.drawRect(0, 0, width-widthLayoutOffset, drawHeight);
                         tPaint.end();
                     }
-                    QListWidgetItem *tRectangle = new QListWidgetItem(QString(), m_formOptionListWidget, QListWidgetItem::UserType +1);
+                    auto *tRectangle = new QListWidgetItem(QString(), m_formOptionListWidget, QListWidgetItem::UserType +1);
                     tRectangle->setData(Qt::DecorationRole, QVariant(m_rectanglePixmap));
                     tRectangle->setSizeHint(sizeHint);
 
-                    QListWidgetItem *tFilledRectangle = new QListWidgetItem(QString(), m_formOptionListWidget, QListWidgetItem::UserType +1);
+                    auto *tFilledRectangle = new QListWidgetItem(QString(), m_formOptionListWidget, QListWidgetItem::UserType +1);
                     tFilledRectangle->setData(Qt::DecorationRole, QVariant(m_filledRectanglePixmap));
                     tFilledRectangle->setSizeHint(sizeHint);
 
@@ -486,11 +486,11 @@ namespace Konversation
                         tPaint.drawEllipse(0, 0, width-widthLayoutOffset, drawHeight);
                         tPaint.end();
                     }
-                    QListWidgetItem *tEllipse = new QListWidgetItem(QString(), m_formOptionListWidget, QListWidgetItem::UserType +1);
+                    auto *tEllipse = new QListWidgetItem(QString(), m_formOptionListWidget, QListWidgetItem::UserType +1);
                     tEllipse->setData(Qt::DecorationRole, QVariant(m_ellipsePixmap));
                     tEllipse->setSizeHint(sizeHint);
 
-                    QListWidgetItem *tFilledEllipse = new QListWidgetItem(QString(), m_formOptionListWidget, QListWidgetItem::UserType +1);
+                    auto *tFilledEllipse = new QListWidgetItem(QString(), m_formOptionListWidget, QListWidgetItem::UserType +1);
                     tFilledEllipse->setData(Qt::DecorationRole, QVariant(m_filledEllipsePixmap));
                     tFilledEllipse->setSizeHint(sizeHint);
 
