@@ -1,15 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  begin:     Fri Jan 25 2002
-  copyright: (C) 2002 by Dario Abatianni
-             (C) 2007 Peter Simonsson <peter.simonsson@gmail.com>
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2007 Peter Simonsson <peter.simonsson@gmail.com>
 */
 
 #ifndef NICK_H
@@ -24,6 +17,12 @@ class Channel;
 
 class Nick : public QTreeWidgetItem
 {
+    public:
+        enum Columns {
+            NicknameColumn = 0,
+            HostmaskColumn = 1
+        };
+
     public:
         Nick(NickListView *listView, Channel* channel,
             const ChannelNickPtr& channelnick);
@@ -37,22 +36,18 @@ class Nick : public QTreeWidgetItem
         void refresh();
         void repositionMe();
 
-    protected:
+    private:
         QString calculateLabel1() const;
         QString calculateLabel2() const;
 
         int getSortingValue() const;
 
-    protected:
+    private:
         ChannelNickPtr m_channelnickptr;
         Channel* m_channel;
 
         int m_flags;
 
-    public:
-        enum Columns {
-            NicknameColumn = 0,
-            HostmaskColumn = 1
-        };
+        Q_DISABLE_COPY(Nick)
 };
 #endif
