@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2005-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef QUERY_H
@@ -39,6 +34,7 @@ class KSqueezedTextLabel;
 class Query : public ChatWindow
 {
     Q_OBJECT
+    friend class Server;
 
     public:
         explicit Query(QWidget* parent, const QString& _name);
@@ -54,14 +50,14 @@ class Query : public ChatWindow
          *  The problem is when you open a query to someone, then the go offline.
          *  This should be fixed maybe?  I don't know.
          */
-        NickInfoPtr getNickInfo();
+        NickInfoPtr getNickInfo() const;
         bool closeYourself(bool askForConfirmation=true) override;
-        bool canBeFrontView() override;
-        bool searchView() override;
+        bool canBeFrontView() const override;
+        bool searchView() const override;
 
         void setChannelEncoding(const QString& encoding) override;
-        QString getChannelEncoding() override;
-        QString getChannelEncodingDefaultDesc() override;
+        QString getChannelEncoding() const override;
+        QString getChannelEncodingDefaultDesc() const override;
         void emitUpdateInfo() override;
 
         /** call this when you see a nick quit from the server.
@@ -70,7 +66,7 @@ class Query : public ChatWindow
         void quitNick(const QString& reason, const QHash<QString, QString> &messageTags);
 
         #ifdef HAVE_QCA2
-        Konversation::Cipher* getCipher();
+        Konversation::Cipher* getCipher() const;
         #endif
 
     Q_SIGNALS:
@@ -83,7 +79,13 @@ class Query : public ChatWindow
         void setEncryptedOutput(bool);
         void connectionStateChanged(Server*, Konversation::ConnectionState);
 
-    protected Q_SLOTS:
+    protected:
+        void setName(const QString& newName) override;
+        void showEvent(QShowEvent* event) override;
+        /** Called from ChatWindow adjustFocus */
+        void childAdjustFocus() override;
+
+    private Q_SLOTS:
         void queryTextEntered();
         void queryPassthroughCommand();
         void sendFileMenu();
@@ -91,13 +93,7 @@ class Query : public ChatWindow
         // connected to IRCInput::textPasted() - used to handle large/multiline pastes
         void textPasted(const QString& text);
         void nickInfoChanged();
-        void updateNickInfo(Server* server, NickInfoPtr nickInfo);
-
-    protected:
-        void setName(const QString& newName) override;
-        void showEvent(QShowEvent* event) override;
-        /** Called from ChatWindow adjustFocus */
-        void childAdjustFocus() override;
+        void updateNickInfo(Server* server, const NickInfoPtr &nickInfo);
 
     private:
         bool awayChanged;
@@ -116,7 +112,10 @@ class Query : public ChatWindow
 
         #ifdef HAVE_QCA2
         //FIXME: We might want to put this into the attendee object (i.e. NickInfo).
-        Konversation::Cipher *m_cipher;
+        mutable Konversation::Cipher *m_cipher;
         #endif
+
+        Q_DISABLE_COPY(Query)
 };
+
 #endif
