@@ -32,9 +32,9 @@ namespace Konversation
         : QDialog(parent)
     {
         setWindowTitle(title);
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
-        QWidget *mainWidget = new QWidget(this);
-        QVBoxLayout *mainLayout = new QVBoxLayout;
+        auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        auto *mainWidget = new QWidget(this);
+        auto *mainLayout = new QVBoxLayout;
         setLayout(mainLayout);
         mainLayout->addWidget(mainWidget);
         QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -433,12 +433,12 @@ namespace Konversation
     : QDialog(parent)
     {
         setWindowTitle(title);
-        QWidget *mainWidget = new QWidget(this);
-        QVBoxLayout *mainLayout = new QVBoxLayout;
+        auto *mainWidget = new QWidget(this);
+        auto *mainLayout = new QVBoxLayout;
         setLayout(mainLayout);
         mainLayout->addWidget(mainWidget);
 
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
         m_okButton = buttonBox->button(QDialogButtonBox::Ok);
         m_okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
         connect(buttonBox, &QDialogButtonBox::rejected, this, &ServerDialog::reject);
@@ -502,11 +502,11 @@ namespace Konversation
     : QDialog(parent)
     {
         setWindowTitle(title);
-        QWidget *mainWidget = new QWidget(this);
-        QVBoxLayout *mainLayout = new QVBoxLayout;
+        auto *mainWidget = new QWidget(this);
+        auto *mainLayout = new QVBoxLayout;
         setLayout(mainLayout);
         mainLayout->addWidget(mainWidget);
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
         m_okButton = buttonBox->button(QDialogButtonBox::Ok);
         m_okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
         connect(buttonBox, &QDialogButtonBox::rejected, this, &ChannelDialog::reject);
