@@ -43,7 +43,7 @@ int main(int argc, char* argv[])
         QStringLiteral(KONVI_VERSION_STRING),
         i18n("A user-friendly IRC client"),
         KAboutLicense::GPL,
-        i18n("Copyright 2002-%1 by the Konversation team", QStringLiteral("2020")),
+        i18n("Copyright 2002-%1 by the Konversation team", QStringLiteral("2022")),
         i18n("Konversation is a client for the Internet Relay Chat (IRC) protocol.\n\n"
         "Meet friends on the net, make new acquaintances and lose yourself in talk about your favorite subject."),
         QStringLiteral("https://konversation.kde.org/"));
@@ -139,7 +139,10 @@ int main(int argc, char* argv[])
 
     KDBusService dbusService(startOptions);
 
-    app.newInstance(&cmdLineParser);
+    if (app.isSessionRestored() && KMainWindow::canBeRestored(1))
+        app.restoreInstance();
+    else
+        app.newInstance(&cmdLineParser);
     app.setCommandLineParser(&cmdLineParser);
 
     QObject::connect(&dbusService, &KDBusService::activateRequested,
