@@ -35,22 +35,25 @@
 #include <KStandardAction>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KConfigGui>
 
 #include <QSplitter>
 #include <QIcon>
 #include <QMenu>
 #include <KWindowSystem>
+#include <KWindowInfo>
 #include <KShortcutsDialog>
 #include <KStandardShortcut>
 #include <KNotifyConfigWidget>
 #include <KGlobalAccel>
+#include <KStartupInfo>
 
 MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
 {
     IrcContextMenus::setupUi(this);
 
     m_hasDirtySettings = false;
-    m_closeApp = false;
+    m_closeOnQuitAction = false;
     m_serverListDialog = nullptr;
     m_trayIcon = nullptr;
     m_settingsDialog = nullptr;
@@ -615,17 +618,6 @@ int MainWindow::confirmQuit()
     return result;
 }
 
-void MainWindow::activateAndRaiseWindow()
-{
-    if (isMinimized())
-        KWindowSystem::unminimizeWindow(winId());
-    else if (Preferences::self()->showTrayIcon() && !isVisible())
-        m_trayIcon->restore();
-
-    KWindowSystem::setOnDesktop(winId(), KWindowSystem::currentDesktop());
-    KWindowSystem::activateWindow(winId());
-}
-
 void MainWindow::quitProgram()
 {
     if (Preferences::self()->showTrayIcon() &&
@@ -633,8 +625,10 @@ void MainWindow::quitProgram()
         confirmQuit() == KMessageBox::Cancel) return;
 
     // will call queryClose()
-    m_closeApp = true;
+    m_closeOnQuitAction = true;
     close();
+    // reset flag in case close was cancelled and close()/queryClose() could be called from elsewhere
+    m_closeOnQuitAction = false;
 }
 
 bool MainWindow::queryClose()
@@ -643,10 +637,9 @@ bool MainWindow::queryClose()
 
     if (!konvApp->isSavingSession())
     {
-        if (sender() == m_trayIcon)
-            m_closeApp = true;
+        const bool isClosingWindowToSystray = !m_closeOnQuitAction && (sender() != m_trayIcon);
 
-        if (Preferences::self()->showTrayIcon() && !m_closeApp)
+        if (Preferences::self()->showTrayIcon() && isClosingWindowToSystray)
         {
             bool doit = KMessageBox::warningContinueCancel(this,
                         i18n("<p>Closing the main window will keep Konversation running in the system tray. "
@@ -656,7 +649,7 @@ bool MainWindow::queryClose()
                         KStandardGuiItem::cancel(),
                         QStringLiteral("HideOnCloseInfo")) == KMessageBox::Continue;
             if (doit)
-                hide();
+                m_trayIcon->hideWindow();
 
             return false;
         }
@@ -670,6 +663,29 @@ bool MainWindow::queryClose()
     return true;
 }
 
+bool MainWindow::restore()
+{
+    // Default restore behavior shows the window based on the flag passed to it
+    // We need to read the respective session data before calling the method,
+    // so we can pass it in.
+    KConfigGroup config(KConfigGui::sessionConfig(), QStringLiteral("1"));
+    const bool show = !config.readEntry("docked", false);
+
+    // TODO: also save & restore any TrayIcon state, needs API in KStatusNotifierItem
+
+    // in case no window is shown & registered, the window manager needs to be told directly the start is done
+    if (!show)
+        KStartupInfo::appStarted();
+
+    return KXmlGuiWindow::restore(1, show);
+}
+
+void MainWindow::saveProperties(KConfigGroup &config)
+{
+    KXmlGuiWindow::saveProperties(config);
+    config.writeEntry("docked", isHidden());
+}
+
 void MainWindow::hideEvent(QHideEvent *e)
 {
     Q_EMIT triggerRememberLine();
@@ -784,14 +800,6 @@ void MainWindow::toggleMenubar(bool dontShowWarning)
     Preferences::self()->setShowMenuBar(m_showMenuBarAction->isChecked());
 }
 
-void MainWindow::focusAndShowErrorMessage(const QString &errorMsg)
-{
-    show();
-    KWindowSystem::demandAttention(winId());
-    KWindowSystem::activateWindow(winId());
-    KMessageBox::error(this, errorMsg);
-}
-
 void MainWindow::openPrefsDialog()
 {
     //An instance of your dialog could be already created and could be cached,
@@ -921,14 +929,37 @@ void MainWindow::toggleVisibility()
     if (isActiveWindow())
     {
         if (Preferences::self()->showTrayIcon())
-            hide();
+            m_trayIcon->hideWindow();
         else
             KWindowSystem::minimizeWindow(winId());
     }
     else
     {
-        activateAndRaiseWindow();
+        activateRaiseAndMoveToDesktop(MoveToDesktop);
     }
 }
 
+void MainWindow::activateAndRaiseWindow()
+{
+    activateRaiseAndMoveToDesktop(NoMoveToDesktop);
+}
 
+void MainWindow::activateRaiseAndMoveToDesktop(MoveToDesktopMode moveToDesktop)
+{
+    if (isMinimized())
+        KWindowSystem::unminimizeWindow(winId());
+    else if (Preferences::self()->showTrayIcon() && !isVisible())
+        m_trayIcon->restoreWindow();
+
+    if (!isActiveWindow())
+    {
+        raise();
+        if (moveToDesktop == MoveToDesktop)
+        {
+            KWindowInfo info(winId(), NET::WMDesktop);
+            if (!info.onAllDesktops())
+                KWindowSystem::setOnDesktop(winId(), KWindowSystem::currentDesktop());
+        }
+        KWindowSystem::activateWindow(winId());
+    }
+}
