@@ -44,10 +44,8 @@ class MainWindow : public KXmlGuiWindow
 
         ViewContainer* getViewContainer() const { return m_viewContainer; }
         Konversation::TrayIcon* systemTrayIcon() const { return m_trayIcon; }
+        bool restore();
 
-        /** Some errors need to be shown, even when konversation is minimized.
-         */
-        void focusAndShowErrorMessage(const QString &errorMsg);
         QSize sizeHint() const override;
 
     Q_SIGNALS:
@@ -82,6 +80,8 @@ class MainWindow : public KXmlGuiWindow
         bool queryClose() override;
         bool event(QEvent* e) override;
 
+        void saveProperties(KConfigGroup &config) override;
+
     private Q_SLOTS:
         /** This is connected to the preferences settingsChanged signal and acts to compress
         *  multiple successively settingsChanged() signals into a single output
@@ -114,6 +114,9 @@ class MainWindow : public KXmlGuiWindow
     private:
         int confirmQuit();
 
+        enum MoveToDesktopMode { NoMoveToDesktop, MoveToDesktop };
+        void activateRaiseAndMoveToDesktop(MoveToDesktopMode moveToDesktop);
+
     private:
         ViewContainer* m_viewContainer;
         Konversation::StatusBar* m_statusBar;
@@ -126,7 +129,7 @@ class MainWindow : public KXmlGuiWindow
 
         /** @see settingsChangedSlot() */
         bool m_hasDirtySettings;
-        bool m_closeApp;
+        bool m_closeOnQuitAction;
 
         Q_DISABLE_COPY(MainWindow)
 };
