@@ -1,19 +1,9 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+
+    SPDX-FileCopyrightText: 2008 Eli J. MacKenzie <argonel at gmail.com>
 */
 
-/*
-  Copyright (C) 2008 Eli J. MacKenzie <argonel at gmail.com>
-*/
-
-
-
 #include "queuetuner.h"
 
 #include "server.h"
@@ -29,27 +19,27 @@
 
 
 QueueTuner::QueueTuner(QWidget* parent, ViewContainer *container)
-: QWidget(parent), m_server(0), m_timer(this),
+: QWidget(parent), m_server(nullptr), m_timer(this),
     m_vis(Preferences::self()->showQueueTunerItem()->value())
 {
     setupUi(this);
 
     m_closeButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     connect(m_closeButton, &QToolButton::clicked, this, &QueueTuner::close);
-    connect(container, SIGNAL(frontServerChanging(Server*)), SLOT(setServer(Server*)));
+    connect(container, &ViewContainer::frontServerChanging, this, &QueueTuner::setServer);
     connect(&m_timer, &QTimer::timeout, this, &QueueTuner::timerFired);
 
-    connect(m_slowRate, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &QueueTuner::slowRateChanged);
-    connect(m_slowType, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &QueueTuner::slowTypeChanged);
-    connect(m_slowInterval, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &QueueTuner::slowIntervalChanged);
+    connect(m_slowRate, QOverload<int>::of(&QSpinBox::valueChanged), this, &QueueTuner::slowRateChanged);
+    connect(m_slowType, QOverload<int>::of(&KComboBox::activated), this, &QueueTuner::slowTypeChanged);
+    connect(m_slowInterval, QOverload<int>::of(&QSpinBox::valueChanged), this, &QueueTuner::slowIntervalChanged);
 
-    connect(m_normalRate, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &QueueTuner::normalRateChanged);
-    connect(m_normalType, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &QueueTuner::normalTypeChanged);
-    connect(m_normalInterval, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &QueueTuner::normalIntervalChanged);
+    connect(m_normalRate, QOverload<int>::of(&QSpinBox::valueChanged), this, &QueueTuner::normalRateChanged);
+    connect(m_normalType, QOverload<int>::of(&KComboBox::activated), this, &QueueTuner::normalTypeChanged);
+    connect(m_normalInterval, QOverload<int>::of(&QSpinBox::valueChanged), this, &QueueTuner::normalIntervalChanged);
 
-    connect(m_fastRate, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &QueueTuner::fastRateChanged);
-    connect(m_fastType, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &QueueTuner::fastTypeChanged);
-    connect(m_fastInterval, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &QueueTuner::fastIntervalChanged);
+    connect(m_fastRate, QOverload<int>::of(&QSpinBox::valueChanged), this, &QueueTuner::fastRateChanged);
+    connect(m_fastType, QOverload<int>::of(&KComboBox::activated), this, &QueueTuner::fastTypeChanged);
+    connect(m_fastInterval, QOverload<int>::of(&QSpinBox::valueChanged), this, &QueueTuner::fastIntervalChanged);
 
     m_timer.setObjectName(QStringLiteral("qTuner"));
 }
@@ -69,7 +59,7 @@ static void rateToWidget(IRCQueue::EmptyingRate& rate, QSpinBox *r, KComboBox* t
 void QueueTuner::serverDestroyed(QObject* ref)
 {
     if (ref == m_server)
-        setServer(0);
+        setServer(nullptr);
 }
 
 void QueueTuner::setServer(Server* newServer)
@@ -90,7 +80,7 @@ void QueueTuner::setServer(Server* newServer)
 
     if (m_server)
     {
-        connect(m_server, SIGNAL(destroyed(QObject*)), SLOT(serverDestroyed(QObject*)));
+        connect(m_server, &QObject::destroyed, this, &QueueTuner::serverDestroyed);
 
         getRates();
     }
@@ -110,7 +100,7 @@ void QueueTuner::timerFired()
 {
     if (m_server)
     {
-        IRCQueue *q=0;
+        IRCQueue *q=nullptr;
 
         q=m_server->m_queues[0];
         m_slowAge->setNum(q->currentWait()/1000);
