@@ -749,13 +749,6 @@ void ChatWindow::msgHelper(const QString& recipient, const QString& message)
 
 void ChatWindow::activateView()
 {
-    for(QWidget* widget = this; widget; widget = widget->parentWidget()) {
-        if (widget->window()) {
-            widget->show();
-            widget->activateWindow();
-            widget->raise();
-        }
-    }
+    Q_EMIT windowActivationRequested();
     Q_EMIT showView(this);
 }
-
