@@ -15,6 +15,7 @@
 #include <QMimeData>
 #include <QRegularExpression>
 
+#include <kcompletion_version.h>
 #include <KMessageBox>
 #include <KCompletionBox>
 #include <KActionCollection>
@@ -40,7 +41,11 @@ IRCInput::IRCInput(QWidget* parent) : KTextEdit(parent)
     // reset completion mode
     setCompletionMode('\0');
     completionBox = new KCompletionBox(this);
+#if KCOMPLETION_VERSION >= QT_VERSION_CHECK(5, 81, 0)
+    connect(completionBox, &KCompletionBox::textActivated, this, &IRCInput::insertCompletion);
+#else
     connect(completionBox, &KCompletionBox::activated, this, &IRCInput::insertCompletion);
+#endif
 
     // widget may not be resized vertically
     setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,QSizePolicy::Fixed));
@@ -214,7 +219,7 @@ void IRCInput::keyPressEvent(QKeyEvent* e)
     switch(e->key())
     {
         case Qt::Key_Tab:
-            emit nickCompletion();
+            Q_EMIT nickCompletion();
             return;
             break;
 
@@ -244,12 +249,12 @@ void IRCInput::keyPressEvent(QKeyEvent* e)
                 // Ctrl+Enter is a special case in which commands should be send as normal messages
                 if ( e->modifiers() & Qt::ControlModifier )
                 {
-                    emit envelopeCommand();
+                    Q_EMIT envelopeCommand();
                 }
                 else
                 {
                     setText(Application::instance()->doAutoreplace(toPlainText(), true).first);
-                    emit submit();
+                    Q_EMIT submit();
                 }
             }
             else
@@ -269,7 +274,7 @@ void IRCInput::keyPressEvent(QKeyEvent* e)
                 if(getCompletionMode()!='\0')
                 {
                     setCompletionMode('\0');
-                    emit endCompletion();
+                    Q_EMIT endCompletion();
                 }
 
                 completionBox->hide();
@@ -388,7 +393,7 @@ void IRCInput::insertFromMimeData(const QMimeData * source)
     {
         //End completion on paste
         setCompletionMode('\0');
-        emit endCompletion();
+        Q_EMIT endCompletion();
 
         bool signal=false;
 
@@ -449,7 +454,7 @@ void IRCInput::insertFromMimeData(const QMimeData * source)
 
               Konversation::sterilizeUnicode(pasteText);
               // signal pasted text
-              emit textPasted(pasteText);
+              Q_EMIT textPasted(pasteText);
               // remember old line, in case the user does not paste eventually
               addHistory(pasteText);
               // delete input text
