@@ -13,6 +13,7 @@
 #include <QTimer>
 #include <QShortcut>
 
+#include <kcompletion_version.h>
 #include <KActionCollection>
 #include <KColorScheme>
 #include <KStandardAction>
@@ -53,7 +54,11 @@ SearchBar::SearchBar(QWidget* parent)
 
     connect(m_timer, &QTimer::timeout, this, &SearchBar::slotFind);
     connect(m_searchEdit, &KLineEdit::textChanged, this, &SearchBar::slotTextChanged);
+#if KCOMPLETION_VERSION >= QT_VERSION_CHECK(5, 81, 0)
+    connect(m_searchEdit, &KLineEdit::returnKeyPressed, this, &SearchBar::slotFindNext);
+#else
     connect(m_searchEdit, &KLineEdit::returnPressed, this, &SearchBar::slotFindNext);
+#endif
     connect(m_findNextButton, &QToolButton::clicked, this, &SearchBar::slotFindNext);
     connect(m_findPreviousButton, &QToolButton::clicked, this, &SearchBar::slotFindPrevious);
     connect(m_closeButton, &QToolButton::clicked, this, &SearchBar::hide);
@@ -132,7 +137,7 @@ void SearchBar::hideEvent(QHideEvent* e)
     QWidget::hideEvent(e);
 
     if (focusedChild())
-        emit hidden();
+        Q_EMIT hidden();
 }
 
 void SearchBar::slotTextChanged()
@@ -151,7 +156,7 @@ void SearchBar::slotFind()
         return;
     }
 
-    emit signalSearchChanged(m_searchEdit->text());
+    Q_EMIT signalSearchChanged(m_searchEdit->text());
 }
 
 void SearchBar::slotFindNext()
@@ -164,7 +169,7 @@ void SearchBar::slotFindNext()
         return;
     }
 
-    emit signalSearchNext();
+    Q_EMIT signalSearchNext();
 }
 
 void SearchBar::slotFindPrevious()
@@ -177,7 +182,7 @@ void SearchBar::slotFindPrevious()
         return;
     }
 
-    emit signalSearchPrevious();
+    Q_EMIT signalSearchPrevious();
 }
 
 void SearchBar::setHasMatch(bool value)
